<?php

namespace Drupal\role_paywall\Form;

use Drupal\Core\Entity\ContentEntityType;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Implements a base form for the role paywall configuration forms.
 */
class RolePaywallFormBase extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'role_paywall_form';
  }

  /**
   * Entity Type Manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(EntityTypeManagerInterface $entity_manager) {
    $this->entityTypeManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
    );
  }

  /**
   * Get a list of all available content entities.
   */
  protected function getContentEntities() {
    $content_entity_types = [];
    $entity_type_definations = $this->entityTypeManager->getDefinitions();

    // It doesn't make sense to apply a paywall to the entities below.
    $unsupported = [
      'block_content',
      'comment',
      'menu_link_content',
      'redirect',
      'shortcut',
      'taxonomy_term',
      'user',
    ];

    // Get list of content entities that have a canonical link.
    foreach ($entity_type_definations as $definition) {
      $id = $definition->get('id');
      $links = $definition->get('links');
      if ($definition instanceof ContentEntityType && !empty($links['canonical']) && !in_array($id, $unsupported)) {
        $content_entity_types[$definition->get('id')] = $definition->get('label');
      }
    }
    return $content_entity_types;
  }

}
